@@ -21,6 +21,7 @@ or mildly randomize graph connectivity in encoder, as a kind of edge Dropout
 
 
 """
+
 from typing import Tuple
 
 import einops
@@ -92,9 +93,6 @@ class Encoder(torch.nn.Module):
         # Build the default graph
         # lat_nodes = torch.zeros((len(lat_lons_heights), input_dim), dtype=torch.float)
         # h3_nodes = torch.zeros((h3.num_hexagons(resolution), output_dim), dtype=torch.float)
-        nodes = torch.zeros(
-            (len(lat_lons) + h3.num_hexagons(resolution), input_dim), dtype=torch.float
-        )
         # Get connections between lat nodes and h3 nodes
         edge_sources = []
         edge_targets = []
@@ -104,7 +102,7 @@ class Encoder(torch.nn.Module):
         edge_index = torch.tensor([edge_sources, edge_targets], dtype=torch.long)
 
         # Use homogenous graph to make it easier
-        self.graph = Data(x=nodes, edge_index=edge_index, edge_attr=self.h3_distances)
+        self.graph = Data(edge_index=edge_index, edge_attr=self.h3_distances)
 
         self.latent_graph = self.create_latent_graph()
 
@@ -169,7 +167,7 @@ class Encoder(torch.nn.Module):
         # Cat with the h3 nodes to have correct amount of nodes, and in right order
         features = einops.rearrange(features, "b n f -> (b n) f")
         out = self.node_encoder(features)  # Encode to 256 from 78
-        edge_attr = self.edge_encoder(self.graph.edge_attr.half())  # Update attributes based on distance
+        edge_attr = self.edge_encoder(self.graph.edge_attr)  # Update attributes based on distance
         # Copy attributes batch times
         edge_attr = einops.repeat(edge_attr, "e f -> (repeat e) f", repeat=batch_size)
         # Expand edge index correct number of times while adding the proper number to the edge index
@@ -195,7 +193,7 @@ class Encoder(torch.nn.Module):
                 dim=1,
             ),
             self.latent_edge_encoder(
-                einops.repeat(self.latent_graph.edge_attr.half(), "e f -> (repeat e) f", repeat=batch_size)
+                einops.repeat(self.latent_graph.edge_attr, "e f -> (repeat e) f", repeat=batch_size)
             ),
         )  # New graph
 
